==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Main/BoardIndex/BoardIndexTabMain.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ

using System;
using System.Collections.Generic;
using System.Text;

namespace nispi
{
	class BoardIndexTabMain
	{
        public BoardIndexView boardIndexView = null;
        public BoardIndexView scBoardIndexView = null;
        public BoardIndexView open2chBoardIndexView = null;
        public BoardIndexView next2chBoardIndexView = null;

        public BoardIndexView jikkyoBoardIndexView = null;
        public BoardIndexView blogbanBoardIndexView = null;
        public BoardIndexView shizuBoardIndexView = null;

        public BoardIndexView vip2chBoardIndexView = null;
        public BoardIndexView machibbsBoardIndexView = null;

        public FavoriteBoardIndexView favoriteBoardIndexView = null;

        public BoardIndexTabMain()
        {
            boardIndexView = new BoardIndexView(Const.BOARD_INDEX_ADDRESS);
            boardIndexView.Name = "boardindex";
            boardIndexView.indexUrl = Const.BOARD_INDEX_ADDRESS;
            boardIndexView.boardIndexControls.tabPageExParts.Text = "2ch  ";
            boardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "2ch";
            boardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 1;


            scBoardIndexView = new BoardIndexView(Const.SC_BOARD_INDEX_ADDRESS);
            scBoardIndexView.Name = "scBoardindex";
            scBoardIndexView.indexUrl = Const.SC_BOARD_INDEX_ADDRESS;
            scBoardIndexView.boardIndexControls.tabPageExParts.Text = "2chSC  ";
            scBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "2chSC";
            scBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 0;

            open2chBoardIndexView = new BoardIndexView(Const.OPEN2CH_BOARD_INDEX_ADDRESS);
            open2chBoardIndexView.Name = "open2ch";
            open2chBoardIndexView.indexUrl = Const.OPEN2CH_BOARD_INDEX_ADDRESS;
            open2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "Open2ch  ";
            open2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "Open2ch";
            open2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 4;

            next2chBoardIndexView = new BoardIndexView(Const.NEXT2CH_BOARD_INDEX_ADDRESS);
            next2chBoardIndexView.Name = "next2ch";
            next2chBoardIndexView.indexUrl = Const.NEXT2CH_BOARD_INDEX_ADDRESS;
            next2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "Next2ch  ";
            next2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "Next2ch";
            next2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 5;

            jikkyoBoardIndexView = new BoardIndexView(Const.JIKKYO_BOARD_INDEX_ADDRESS);
            jikkyoBoardIndexView.Name = "jikkyo";
            jikkyoBoardIndexView.indexUrl = Const.JIKKYO_BOARD_INDEX_ADDRESS;
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.Text = "jikkyo  ";
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "jikkyo";
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 6;

            blogbanBoardIndexView = new BoardIndexView(Const.BLOGBAN_BOARD_INDEX_ADDRESS);
            blogbanBoardIndexView.Name = "blogban";
            blogbanBoardIndexView.indexUrl = Const.BLOGBAN_BOARD_INDEX_ADDRESS;
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.Text = "blogban  ";
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "blogban";
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 7;

            shizuBoardIndexView = new BoardIndexView(Const.SHIZU_BOARD_INDEX_ADDRESS);
            shizuBoardIndexView.Name = "shizu";
            shizuBoardIndexView.indexUrl = Const.SHIZU_BOARD_INDEX_ADDRESS;
            shizuBoardIndexView.boardIndexControls.tabPageExParts.Text = " ";
            shizuBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "";
            shizuBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 8;

            vip2chBoardIndexView = new BoardIndexView(Const.VIP2CH_BOARD_INDEX_ADDRESS);
            vip2chBoardIndexView.Name = "vip2ch";
            vip2chBoardIndexView.indexUrl = Const.VIP2CH_BOARD_INDEX_ADDRESS;
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "VIP2ch  ";
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "VIP2ch";
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 9;

            machibbsBoardIndexView = new BoardIndexView(Const.MACHIBBS_BOARD_INDEX_ADDRESS);
            machibbsBoardIndexView.Name = "machibbs";
            machibbsBoardIndexView.indexUrl = Const.MACHIBBS_BOARD_INDEX_ADDRESS;
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.Text = "܂BBS  ";
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "܂BBS";
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 10;
            
            favoriteBoardIndexView = new FavoriteBoardIndexView();
            favoriteBoardIndexView.Name = "favorite";
            favoriteBoardIndexView.indexUrl = "favorite";
            favoriteBoardIndexView.boardIndexControls.tabPageExParts.Text = "Cɓ";
            favoriteBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 2;


            Const.form.boardIndexTabControlParts.SelectedTab = boardIndexView.boardIndexControls.tabPageExParts;
        }
    }
}

==> AgeOn2.7_source.zip: AgeOn2.7_source/nispi/Controls/Main/BoardIndex/BoardIndexTabMain.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ

using System;
using System.Collections.Generic;
using System.Text;

namespace nispi
{
	class BoardIndexTabMain
	{
        public BoardIndexView boardIndexView = null;
        public BoardIndexView scBoardIndexView = null;
        public BoardIndexView open2chBoardIndexView = null;
        public BoardIndexView next2chBoardIndexView = null;

        public BoardIndexView jikkyoBoardIndexView = null;
        //public BoardIndexView blogbanBoardIndexView = null;
        public BoardIndexView shizuBoardIndexView = null;

        public BoardIndexView vip2chBoardIndexView = null;
        public BoardIndexView machibbsBoardIndexView = null;

        public FavoriteBoardIndexView favoriteBoardIndexView = null;

        public BoardIndexTabMain()
        {
            boardIndexView = new BoardIndexView(Const.BOARD_INDEX_ADDRESS);
            boardIndexView.Name = "boardindex";
            boardIndexView.indexUrl = Const.BOARD_INDEX_ADDRESS;
            boardIndexView.boardIndexControls.tabPageExParts.Text = "2ch.net";
            boardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "2ch.net";
            boardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 1;


            scBoardIndexView = new BoardIndexView(Const.SC_BOARD_INDEX_ADDRESS);
            scBoardIndexView.Name = "scBoardindex";
            scBoardIndexView.indexUrl = Const.SC_BOARD_INDEX_ADDRESS;
            scBoardIndexView.boardIndexControls.tabPageExParts.Text = "2chSC";
            scBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "2chSC";
            scBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 0;

            open2chBoardIndexView = new BoardIndexView(Const.OPEN2CH_BOARD_INDEX_ADDRESS);
            open2chBoardIndexView.Name = "open2ch";
            open2chBoardIndexView.indexUrl = Const.OPEN2CH_BOARD_INDEX_ADDRESS;
            open2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "Open2ch";
            open2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "Open2ch";
            open2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 4;

            next2chBoardIndexView = new BoardIndexView(Const.NEXT2CH_BOARD_INDEX_ADDRESS);
            next2chBoardIndexView.Name = "next2ch";
            next2chBoardIndexView.indexUrl = Const.NEXT2CH_BOARD_INDEX_ADDRESS;
            next2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "Next2ch";
            next2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "Next2ch";
            next2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 5;

            jikkyoBoardIndexView = new BoardIndexView(Const.JIKKYO_BOARD_INDEX_ADDRESS);
            jikkyoBoardIndexView.Name = "jikkyo";
            jikkyoBoardIndexView.indexUrl = Const.JIKKYO_BOARD_INDEX_ADDRESS;
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.Text = "jikkyo";
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "jikkyo";
            jikkyoBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 6;

            /*blogbanBoardIndexView = new BoardIndexView(Const.BLOGBAN_BOARD_INDEX_ADDRESS);
            blogbanBoardIndexView.Name = "blogban";
            blogbanBoardIndexView.indexUrl = Const.BLOGBAN_BOARD_INDEX_ADDRESS;
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.Text = "blogban";
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "blogban";
            blogbanBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 7;*/

            shizuBoardIndexView = new BoardIndexView(Const.SHIZU_BOARD_INDEX_ADDRESS);
            shizuBoardIndexView.Name = "shizu";
            shizuBoardIndexView.indexUrl = Const.SHIZU_BOARD_INDEX_ADDRESS;
            shizuBoardIndexView.boardIndexControls.tabPageExParts.Text = "";
            shizuBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "";
            shizuBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 8;

            vip2chBoardIndexView = new BoardIndexView(Const.VIP2CH_BOARD_INDEX_ADDRESS);
            vip2chBoardIndexView.Name = "vip2ch";
            vip2chBoardIndexView.indexUrl = Const.VIP2CH_BOARD_INDEX_ADDRESS;
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.Text = "VIP2ch";
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "VIP2ch";
            vip2chBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 9;

            machibbsBoardIndexView = new BoardIndexView(Const.MACHIBBS_BOARD_INDEX_ADDRESS);
            machibbsBoardIndexView.Name = "machibbs";
            machibbsBoardIndexView.indexUrl = Const.MACHIBBS_BOARD_INDEX_ADDRESS;
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.Text = "܂BBS";
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.ToolTipText = "܂BBS";
            machibbsBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 10;
            
            favoriteBoardIndexView = new FavoriteBoardIndexView();
            favoriteBoardIndexView.Name = "favorite";
            favoriteBoardIndexView.indexUrl = "favorite";
            favoriteBoardIndexView.boardIndexControls.tabPageExParts.Text = "Cɓ";
            favoriteBoardIndexView.boardIndexControls.tabPageExParts.ImageIndex = 2;


            Const.form.boardIndexTabControlParts.SelectedTab = scBoardIndexView.boardIndexControls.tabPageExParts;
        }
    }
}
